@@ -236,7 +236,8 @@ read.genalex <- function(genalex, ploidy=2, geo=FALSE, region=FALSE,
   gencall  <- match.call()
 
   all.info <- strsplit(readLines(genalex, n = 2), sep)
-  gena     <- read.table(genalex, sep = sep, header = TRUE, skip = 2, 
+  cskip    <- ifelse("connection" %in% class(genalex), 0, 2)
+  gena     <- read.table(genalex, sep = sep, header = TRUE, skip = cskip, 
                          stringsAsFactors = FALSE, check.names = FALSE)
   num.info <- as.numeric(all.info[[1]])
   pop.info <- all.info[[2]][-c(1:3)]
@@ -374,7 +375,7 @@ read.genalex <- function(genalex, ploidy=2, geo=FALSE, region=FALSE,
   res.gid@call <- gencall
   
   # Keep the name if it's a URL
-  if (length(grep("://", genalex)) < 1){
+  if (length(grep("://", genalex)) < 1 & !"connection" %in% class(genalex)){
     res.gid@call[2] <- basename(genalex)
   }
   if (region){
